pub enum Error<'a> {
ParseError(Err<Error<Vec<u8>>>),
UnexpectedData(&'a [u8]),
}Expand description
Error type returned in parse_btsnoop_file if parsing failed.
Variants
ParseError(Err<Error<Vec<u8>>>)
Error parsing the input data.
UnexpectedData(&'a [u8])
The input data was successfully parsed, but there is data leftover. This can be a symptom of malformed data if the length field in the packet is wrong.